@@ -6,9 +6,9 @@ package Devel::EndStats;
 #use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-05-01'; # DATE
+our $DATE = '2023-05-12'; # DATE
 our $DIST = 'Devel-EndStats'; # DIST
-our $VERSION = '0.210'; # VERSION
+our $VERSION = '0.211'; # VERSION
 
 our %opts = (
     verbose      => 0,
@@ -88,10 +88,10 @@ sub import {
         };
 
         my $memsize1 = _get_memsize() if $opts{show_memsize};
-        my $st = $opts{time_hires} ? [Time::HiRes::gettimeofday] : time();
+        my $st = $opts{time_hires} ? [Time::HiRes::gettimeofday()] : time();
         my $res;
         if (wantarray) { $res = [CORE::require $arg] } else { $res = CORE::require $arg }
-        my $iv = $opts{time_hires} ? Time::HiRes::tv_interval($st) : time()-$st;
+        my $iv = $opts{time_hires} ? Time::HiRes::tv_interval($st, [Time::HiRes::gettimeofday()]) : time()-$st;
         my $memsize2 = _get_memsize() if $opts{show_memsize};
 
         # still can't make exclusive time work
@@ -263,7 +263,7 @@ Devel::EndStats - Display run time and dependencies after running code
 
 =head1 VERSION
 
-This document describes version 0.210 of Devel::EndStats (from Perl distribution Devel-EndStats), released on 2023-05-01.
+This document describes version 0.211 of Devel::EndStats (from Perl distribution Devel-EndStats), released on 2023-05-12.
 
 =head1 SYNOPSIS
 
